@@ -249,7 +249,7 @@ sub _subrequest
     args  => $original_r->args,
   );
   local $ENV{SCRIPT_NAME} = $uri;
-  local $ENV{REQUEST_URI} = $uri;
+#  local $ENV{REQUEST_URI} = $uri;
   local $ENV{SCRIPT_FILENAME} = $file;
   $s->context->setup_request( $r, $s->context->cgi );
   $s->context->execute( $args, 1 );
